
//          Copyright Oliver Kowalke 2009.
// Distributed under the Boost Software License, Version 1.0.
//    (See accompanying file LICENSE_1_0.txt or copy at
//          http://www.boost.org/LICENSE_1_0.txt)

#ifndef BOOST_COROUTINES_COROUTINE_H
#define BOOST_COROUTINES_COROUTINE_H

#ifdef BOOST_COROUTINES_UNIDIRECT
#include <boost/coroutine/v2/coroutine.hpp>
#else
#include <boost/coroutine/v1/coroutine.hpp>
#endif

#endif // BOOST_COROUTINES_COROUTINE_H
